@@ -161,10 +161,10 @@ check_application (EelOpenWithDialog *dialog)
 		keyfile = g_key_file_new ();
 		if (g_key_file_load_from_file (keyfile, dialog->details->desktop_file,
 					       0, NULL)) {
-			command = g_strdup (g_key_file_get_string (keyfile,
-								   DESKTOP_ENTRY_GROUP,
-				      			           GNOME_DESKTOP_ITEM_EXEC,
-								   NULL));
+			command = g_key_file_get_string (keyfile,
+							 DESKTOP_ENTRY_GROUP,
+				      			 GNOME_DESKTOP_ITEM_EXEC,
+							 NULL);
 		}
 		g_key_file_free (keyfile);
 	}
@@ -287,6 +287,7 @@ add_or_find_application (EelOpenWithDialog *dialog)
 		} else {
 			app = NULL;
 		}
+		g_free (app_name);
 	}
 
 	if (!app) {
@@ -480,7 +481,7 @@ eel_open_with_dialog_add_icon_idle (EelOpenWithDialog *dialog)
 		}
 		
 		if (g_path_is_absolute (file)) {
-			pixbuf = gdk_pixbuf_new_from_file_at_size (file, 24, 24, 0);
+			pixbuf = gdk_pixbuf_new_from_file_at_size (file, 24, 24, NULL);
 			long_operation = TRUE;
 		} else {
 			char *icon_no_extension;
